@@ -1,12 +1,10 @@
-# -*- coding: utf-8 -*-
-
 """Tests sqlparse.parse()."""
+from io import StringIO
 
 import pytest
 
 import sqlparse
 from sqlparse import sql, tokens as T
-from sqlparse.compat import StringIO, text_type
 
 
 def test_parse_tokenize():
@@ -102,6 +100,12 @@ def test_parse_square_brackets_notation_isnt_too_greedy():
     assert t[0].tokens[-1].get_real_name() == '[bar]'
 
 
+def test_parse_square_brackets_notation_isnt_too_greedy2():
+    # see issue583
+    t = sqlparse.parse('[(foo[i])]')[0].tokens
+    assert isinstance(t[0], sql.SquareBrackets)  # not Identifier!
+
+
 def test_parse_keyword_like_identifier():
     # see issue47
     t = sqlparse.parse('foo.key')[0].tokens
@@ -409,42 +413,42 @@ def test_dbldollar_as_literal(sql, is_literal):
 
 
 def test_non_ascii():
-    _test_non_ascii = u"insert into test (id, name) values (1, 'тест');"
+    _test_non_ascii = "insert into test (id, name) values (1, 'тест');"
 
     s = _test_non_ascii
     stmts = sqlparse.parse(s)
     assert len(stmts) == 1
     statement = stmts[0]
-    assert text_type(statement) == s
+    assert str(statement) == s
     assert statement._pprint_tree() is None
 
     s = _test_non_ascii.encode('utf-8')
     stmts = sqlparse.parse(s, 'utf-8')
     assert len(stmts) == 1
     statement = stmts[0]
-    assert text_type(statement) == _test_non_ascii
+    assert str(statement) == _test_non_ascii
     assert statement._pprint_tree() is None
 
 
 def test_get_real_name():
     # issue 369
-    s = u"update a t set t.b=1"
+    s = "update a t set t.b=1"
     stmts = sqlparse.parse(s)
     assert len(stmts) == 1
-    assert 'a' == stmts[0].get_real_name()
-    assert 't' == stmts[0].get_alias()
+    assert 'a' == stmts[0].tokens[2].get_real_name()
+    assert 't' == stmts[0].tokens[2].get_alias()
 
 
 def test_from_subquery():
     # issue 446
-    s = u'from(select 1)'
+    s = 'from(select 1)'
     stmts = sqlparse.parse(s)
     assert len(stmts) == 1
     assert len(stmts[0].tokens) == 2
     assert stmts[0].tokens[0].value == 'from'
     assert stmts[0].tokens[0].ttype == T.Keyword
 
-    s = u'from (select 1)'
+    s = 'from (select 1)'
     stmts = sqlparse.parse(s)
     assert len(stmts) == 1
     assert len(stmts[0].tokens) == 3
